==> members-facade-2.0.0-20191106.080807-154-sources.jar: com/bizvane/members/facade/constants/AdvancedSearchConstant.java <==
package com.bizvane.members.facade.constants;

/**
 * Created by Administrator on 2018\8\15 0015.
 */
public class AdvancedSearchConstant {

    //因为es field  设置为小写

    public static final String MBRMEMBERID = "mbrMemberId";
    public static final String VALID = "valid";
    public static final String SYSCOMPANYID = "sysCompanyId";
    public static final String MEMBERCODE = "memberCode";
    public static final String PHONE = "phone.keyword";
    public static final String CARDNO = "cardNo.keyword";
    public static final String NAME = "name";
    public static final String BRANDID = "brandId";
    public static final String LEVELID = "levelId";
    public static final String LABEL_NAMES = "labelNames";
    public static final String EMAIL = "email.keyword";
    public static final String EMAILSTATUS = "emailStatus";

    public static final String LABEL_IDS = "labelIds";

    public static final String WXUNIONID = "wxUnionId";

    public static final String GENDER = "gender";
    public static final String ERPID = "erpId.keyword";
    //年龄转生日
    public static final String AGE = "birthday";
    public static final String INTEGRAL = "countIntegral";
    public static final String FOCUS = "focus";
    public static final String CARDSTATUS = "cardStatus";
    public static final String WXMEMBERS = "wxMembers";

    //生命周期
    public static final String MEMBERLIVENESS = "memberLiveness";
    /**
     * public static final String ACTIVEMEMBER = "activemember";
     * public static final String SILENCEMEMBER = "silencemember";
     * public static final String VERGESLEEPMEMBER = "vergesleepmember";
     * public static final String DORMANCYMEMBER = "dormancymember";
     * public static final String AWAYMEMBER = "awaymember";
     **/

    public static final String ACTIVESTORE = "activeStore";
    public static final String SERVICEGUIDE = "serviceGuideId";
    public static final String SERVICESTORE = "serviceStoreId";
    public static final String SERVICEGROUP = "serviceStoreId";
    public static final String OPENCARDGUIDE = "openCardGuideId";
    public static final String OPENCARDSTORE = "openCardStoreId";
    public static final String FIRSTBUYTIME = "firstBuyTime";
    public static final String LASTBUYTIME = "lastBuyTime";
    public static final String CONSUMEAMOUNT = "consumeAmount";
    public static final String CONSUMENUMBER = "consumeNumber";
    public static final String REFUNDNUMBER = "refundNumber";
    public static final String REFUNDAMOUNT = "refundAmount";
    public static final String PCTAMOUNT = "pctAmount";
    public static final String DISCOUNTRATE = "discountRate";
    public static final String APRNUMBER = "aprNumber";
    public static final String PROVINCE = "province";
    public static final String CITY = "city";
    public static final String COUNTY = "county";
    public static final String BIRTHDAYMD = "birthdayMd";
    public static final String NEWMEMBER = "groupNewMember";
    public static final String OPENCARDTIME = "openCardTime";
    public static final String BINDCARDTIME = "bindCardTime";
    public static final String EXTENDCODE = "extendCode";
    public static final String EXTENDVALUE = "extendValue";

    public static final String TEXTPROPERTY = "textProperty";
    public static final String DATEPROPERTY = "dateProperty";

    public static final String DATEFROM = "dateFrom";
    public static final String MEMBERCOMMENT = "memberComment";
    public static final String WXNICK = "wxNick";
    public static final String COMPANYGUIDEFRIENDS = "companyGuideFriends";

    public static final String DATAINTEGRITYPERCENTAGE = "dataIntegrityPercentage";

    public static final String CREATEDATE = "createDate";

    public static final String OPENCARDCHANNELID = "openCardChannelId";


    // 微信粉丝渠道(t_mbr_wx_channel)
    public static final String WX_CHANNEL_CREATEDATE = "createDate";
    public static final String WX_CHANNEL_FOCUS = "focus";
    public static final String WX_CHANNEL_CARDSTATUS = "cardStatus";
    public static final String WX_CHANNEL_MINIPROGRAM = "miniProgram";
    public static final String WX_CHANNEL_LASTESTIME = "lastEsTime";
    public static final String WX_CHANNEL_BRANDID = "brandId";

    public static final String OPENCARDTIMEMD = "openCardTimeMD";

    public static final String taobaoBindStatus = "taobaoBindStatus";

    public static final String COMPANY_FRIEND = "companyFriend";

    public static final String SKUS = "skus";
    public static final String CHANNEL = "channel";
    //升级时间
    public static final String LEVELUPTIME = "levelUpTime";

    public static final String BABYBIRTHDAYMD = "babyBirthdayMd";


    public static final String LASTCHATTIME = "lastChatTime";


    public static final String MBRWXCHANNELID = "mbrWxChannelId";

    public static final String MARKREAD = "markRead";

    public static final String NAME_KEYWORD = "name.keyword";

    public static final String CONSUMEAMOUNT3 = "consumeAmount3";


    public static final String OPENID = "openId";


    public static final String BIRTHDAY = "birthday";
    //////分销

    public static final String DISTRIBUTIONSTATUS = "distributionStatus";

    public static final String DISTRIBCREATEDATE = "distribCreateDate";

    public static final String DISTRIBMODIFYDATE = "distribModifyDate";

    public static final String DISTRIBBINDCREATEDATE = "distribBindCreateDate";

    public static final String CONTRIBUTIONCOMMISSION = "contributionCommission";

    public static final String COMMISSIONBALANCE = "commissionBalance";

    public static final String SUMCOMMISSION = "sumCommission";

    public static final String SUPERIORMEMBERCODE = "superiorMemberCode";

    public static final String ALLCHANNELIDS = "allChannelIds";

    public static final String DISTRIBBINDSTATUS = "distribBindStatus";


    public static final String SKUCATE1S = "skuCate1s.keyword";

    public static final String SKUCATE2S = "skuCate2s.keyword";

    public static final String SKUCATE3S = "skuCate3s.keyword";

    public static final String SKUBRANDS = "skuBrands.keyword";

    public static final String SKUPROPERTYVALUES = "skuPropertyValues.keyword";

    public static final String skuSpces = "skuSpces.keyword";
}

==> members-facade-2.0.0-20191216.071911-180-sources.jar: com/bizvane/members/facade/constants/AdvancedSearchConstant.java <==
package com.bizvane.members.facade.constants;

/**
 * Created by Administrator on 2018\8\15 0015.
 */
public class AdvancedSearchConstant {

    //因为es field  设置为小写

    public static final String MBRMEMBERID = "mbrMemberId";
    public static final String VALID = "valid";
    public static final String SYSCOMPANYID = "sysCompanyId";
    public static final String MEMBERCODE = "memberCode";
    public static final String PHONE = "phone.keyword";
    public static final String CARDNO = "cardNo.keyword";
    public static final String NAME = "name";
    public static final String BRANDID = "brandId";
    public static final String LEVELID = "levelId";
    public static final String LABEL_NAMES = "labelNames";
    public static final String EMAIL = "email.keyword";
    public static final String EMAILSTATUS = "emailStatus";

    public static final String LABEL_IDS = "labelIds";

    public static final String WXUNIONID = "wxUnionId";

    public static final String GENDER = "gender";
    public static final String ERPID = "erpId.keyword";
    //年龄转生日
    public static final String AGE = "birthday";
    public static final String INTEGRAL = "countIntegral";
    public static final String FOCUS = "focus";
    public static final String CARDSTATUS = "cardStatus";
    public static final String WXMEMBERS = "wxMembers";

    //生命周期
    public static final String MEMBERLIVENESS = "memberLiveness";
    /**
     * public static final String ACTIVEMEMBER = "activemember";
     * public static final String SILENCEMEMBER = "silencemember";
     * public static final String VERGESLEEPMEMBER = "vergesleepmember";
     * public static final String DORMANCYMEMBER = "dormancymember";
     * public static final String AWAYMEMBER = "awaymember";
     **/

    public static final String ACTIVESTORE = "activeStore";
    public static final String SERVICEGUIDE = "serviceGuideId";
    public static final String SERVICESTORE = "serviceStoreId";
    public static final String SERVICEGROUP = "serviceStoreId";
    public static final String OPENCARDGUIDE = "openCardGuideId";
    public static final String OPENCARDSTORE = "openCardStoreId";
    public static final String FIRSTBUYTIME = "firstBuyTime";
    public static final String LASTBUYTIME = "lastBuyTime";
    public static final String CONSUMEAMOUNT = "consumeAmount";
    public static final String CONSUMENUMBER = "consumeNumber";
    public static final String REFUNDNUMBER = "refundNumber";
    public static final String REFUNDAMOUNT = "refundAmount";
    public static final String PCTAMOUNT = "pctAmount";
    public static final String DISCOUNTRATE = "discountRate";
    public static final String APRNUMBER = "aprNumber";
    public static final String PROVINCE = "province";
    public static final String CITY = "city";
    public static final String COUNTY = "county";
    public static final String BIRTHDAYMD = "birthdayMd";
    public static final String NEWMEMBER = "groupNewMember";
    public static final String OPENCARDTIME = "openCardTime";
    public static final String BINDCARDTIME = "bindCardTime";
    public static final String EXTENDCODE = "extendCode";
    public static final String EXTENDVALUE = "extendValue";

    public static final String TEXTPROPERTY = "textProperty";
    public static final String DATEPROPERTY = "dateProperty";

    public static final String DATEFROM = "dateFrom";
    public static final String MEMBERCOMMENT = "memberComment";
    public static final String WXNICK = "wxNick";
    public static final String COMPANYGUIDEFRIENDS = "companyGuideFriends";

    public static final String DATAINTEGRITYPERCENTAGE = "dataIntegrityPercentage";

    public static final String CREATEDATE = "createDate";

    public static final String OPENCARDCHANNELID = "openCardChannelId";


    // 微信粉丝渠道(t_mbr_wx_channel)
    public static final String WX_CHANNEL_CREATEDATE = "createDate";
    public static final String WX_CHANNEL_FOCUS = "focus";
    public static final String WX_CHANNEL_CARDSTATUS = "cardStatus";
    public static final String WX_CHANNEL_MINIPROGRAM = "miniProgram";
    public static final String WX_CHANNEL_LASTESTIME = "lastEsTime";
    public static final String WX_CHANNEL_BRANDID = "brandId";

    public static final String OPENCARDTIMEMD = "openCardTimeMD";

    public static final String taobaoBindStatus = "taobaoBindStatus";

    public static final String COMPANY_FRIEND = "companyFriend";

    public static final String SKUS = "skus";
    public static final String CHANNEL = "channel";
    //升级时间
    public static final String LEVELUPTIME = "levelUpTime";

    public static final String BABYBIRTHDAYMD = "babyBirthdayMd";


    public static final String LASTCHATTIME = "lastChatTime";


    public static final String MBRWXCHANNELID = "mbrWxChannelId";

    public static final String MARKREAD = "markRead";

    public static final String NAME_KEYWORD = "name.keyword";

    public static final String CONSUMEAMOUNT3 = "consumeAmount3";


    public static final String OPENID = "openId";


    public static final String BIRTHDAY = "birthday";
    //////分销

    public static final String DISTRIBUTIONSTATUS = "distributionStatus";

    public static final String DISTRIBCREATEDATE = "distribCreateDate";

    public static final String DISTRIBMODIFYDATE = "distribModifyDate";

    public static final String DISTRIBBINDCREATEDATE = "distribBindCreateDate";

    public static final String CONTRIBUTIONCOMMISSION = "contributionCommission";

    public static final String COMMISSIONBALANCE = "commissionBalance";

    public static final String SUMCOMMISSION = "sumCommission";

    public static final String SUPERIORMEMBERCODE = "superiorMemberCode";

    public static final String ALLCHANNELIDS = "allChannelIds";

    public static final String DISTRIBBINDSTATUS = "distribBindStatus";


    public static final String SKUCATE1S = "skuCate1s.keyword";

    public static final String SKUCATE2S = "skuCate2s.keyword";

    public static final String SKUCATE3S = "skuCate3s.keyword";

    public static final String SKUBRANDS = "skuBrands.keyword";

    public static final String SKUPROPERTYVALUES = "skuPropertyValues.keyword";

    public static final String skuSpces = "skuSpces.keyword";

    public static final String CHANGE_DATE = "changeDate";

    public static final String MBR_INTEGRAL_RECORD_ID = "mbrIntegralRecordId";

    public static final String CHANGE_BILLS = "changeBills";

    public static final String CHANGE_INTEGRAL = "changeIntegral";

    public static final String CHANGE_WAY = "changeWay";

    public static final String BUSINESS_WAY = "businessWay";

    public static final String  MEMBER_NAME= "memberName";
    public static final String  MEMBER_NAME_UNIQUE= "memberName.keyword";

    public static final String  MEMBER_CARD_NO= "memberCardNo";
}
